<?php

/**
 * Data file for timezone "Etc/GMT-2".
 * Compiled from olson file "etcetera", version 8.3.
 *
 * @package    agavi
 * @subpackage translation
 *
 * @copyright  Authors
 * @copyright  The Agavi Project
 *
 * @since      0.11.0
 *
 * @version    $Id: Etc_47_GMT_45_2.php 4640 2011-04-16 11:13:19Z david $
 */

return array (
  'types' => 
  array (
  ),
  'rules' => 
  array (
  ),
  'finalRule' => 
  array (
    'type' => 'static',
    'name' => 'GMT-2',
    'offset' => 7200,
    'startYear' => -2147483647,
  ),
  'source' => 'etcetera',
  'version' => '8.3',
  'name' => 'Etc/GMT-2',
);

?>